==> enterprisemodules-ora_config-3.23.4.tar.gz: enterprisemodules-ora_config-3.23.4/lib/puppet/type/ora_rman_config/device.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:device) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access

  desc <<-DESC
    Manage rman configuration for `DEVICE`.
    The configuration can be set to default by setting the value for device to 'clear' (case insensitive).

    ora_rman_config { 'SID':
      ...
      device => {
        'DISK' => 'PARALLELISM 2 BACKUP TYPE TO COMPRESSED BACKUPSET',
        'SBT'  => 'CLEAR',
      },
      ...
    }
  DESC

  data_type("Optional[Hash[Enum['DISK','SBT'],String[1]]]")

  to_translate_to_resource do |raw_resource|
    raw_resource['DEVICE']
  end

  def insync?(is)
    return true if is == should

    checkdiff(is, should).empty?
  end

  def change_to_s(currentvalue, newvalue)
    diff = checkdiff(currentvalue, newvalue)
    messages = []
    diff.each_pair do |type, val|
      messages << if val.casecmp('clear').zero?
                    "clearing device for type #{type}"
                  else
                    "changing device for type #{type} to #{val}"
                  end
    end
    messages.join(', ')
  end

  on_modify do
    diff = checkdiff(provider.device, should)
    diff.each_pair do |type, val|
      rman("configure device type #{type} #{val}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
    end
  end

  def checkdiff(is, should)
    my_should = should
    my_should.each_pair do |key, val|
      if val.to_s.casecmp('clear').zero?
        my_should.delete(key) if is[key].to_s.include?('(default)') || is[key].nil?
      elsif is[key].to_s.casecmp(val.to_s).zero?
        my_should.delete(key)
      end
    end
  end
end

==> enterprisemodules-ora_config-3.26.2.tar.gz: enterprisemodules-ora_config-3.26.2/lib/puppet/type/ora_rman_config/device.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:device) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access

  desc <<-DESC
    Manage rman configuration for `DEVICE`.
    The configuration can be set to default by setting the value for device to 'clear' (case insensitive).

    ora_rman_config { 'SID':
      ...
      device => {
        'DISK' => 'PARALLELISM 2 BACKUP TYPE TO COMPRESSED BACKUPSET',
        'SBT'  => 'CLEAR',
      },
      ...
    }
  DESC

  data_type("Optional[Hash[Enum['DISK','SBT'],String[1]]]")

  to_translate_to_resource do |raw_resource|
    raw_resource['DEVICE']
  end

  def insync?(is)
    return true if is == should

    checkdiff(is, should).empty?
  end

  def change_to_s(currentvalue, newvalue)
    diff = checkdiff(currentvalue, newvalue)
    messages = []
    diff.each_pair do |type, val|
      messages << if val.casecmp('clear')&.zero?
                    "clearing device for type #{type}"
                  else
                    "changing device for type #{type} to #{val}"
                  end
    end
    messages.join(', ')
  end

  on_modify do
    diff = checkdiff(provider.device, should)
    diff.each_pair do |type, val|
      rman("configure device type #{type} #{val}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
    end
  end

  def checkdiff(is, should)
    my_should = should
    my_should.each_pair do |key, val|
      if val.to_s.casecmp('clear')&.zero?
        my_should.delete(key) if is[key].to_s.include?('(default)') || is[key].nil?
      elsif is[key].to_s.casecmp(val.to_s)&.zero?
        my_should.delete(key)
      end
    end
  end
end
